stereo.tools.CellTypeAnno
=========================

.. currentmodule:: stereo.tools

.. autoclass:: CellTypeAnno

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CellTypeAnno.__init__
      ~CellTypeAnno.add_result
      ~CellTypeAnno.check_param
      ~CellTypeAnno.concat_top_corr_files
      ~CellTypeAnno.fit
      ~CellTypeAnno.get_params
      ~CellTypeAnno.merge_subsample_result
      ~CellTypeAnno.merge_subsample_result_filter
      ~CellTypeAnno.sparse2array
      ~CellTypeAnno.split_dataframe
   
   

   
   
   